import os
import time
import hcpsdk

if __name__ == '__main__':

    a = hcpsdk.NativeAuthorization('n', 'n01')
    t = hcpsdk.Target('n1.m.hcp1.snomis.local', a, port=443)
    c = hcpsdk.Connection(t)

    r = c.GET('/rest/hcpsdk/testfile2.mp4')
    print(c.response_status, c.response_reason)

    print('len(c.read(1024)) = {}'.format(len(c.read(1024))))

    for i in range(10):
        print('.', end='', flush=True)
        time.sleep(1)
    print()

    try:
        print('len(c.read()) = {}'.format(len(c.read())))
    except Exception as e:
        print(str(e))
        raise e
    finally:
        c.close()




import sys
from os.path import join, normpath
import time
import pprint
import http.client
import hcpsdk

T_NAMESPACE = 'n1.m.hcp73.archivas.com'
T_DAAC      = 'n'
T_DAAC_PWD  = 'n01'
T_PORT      = 443
T_DEBUG     = True

T_OBJ            = 128            # the object we will use in a run (from objs)
T_NAME = '/rest/hcpsdk/failtest'  # path to write to

T_OBJ = '256kbfile'  # the source object


if __name__ == '__main__':
    if T_DEBUG:
        import logging
        logging.basicConfig(level=logging.DEBUG, style='{', format='{levelname:>5s} {msg}')
        # noinspection PyShadowingBuiltins
        print = pprint = logging.info

    # the place where we will find the needed source objects
    if sys.platform == 'win32':
        T_INPATH = 'd:\\__files'
    elif sys.platform == 'darwin':
        T_INPATH = '/Volumes/dev/__files'
    else:
        sys.exit('source path is undefined')
    T_OBJPATH = join(T_INPATH, T_OBJ)

    print("--> Init <hcptarget> object")
    try:
        auth = hcpsdk.NativeAuthorization(T_DAAC, T_DAAC_PWD)
        hcptarget = hcpsdk.Target(T_NAMESPACE, auth, T_PORT)
    except hcpsdk.HcpsdkError as e:
        sys.exit("Fatal: {}".format(e.errText))

    print("--> Init <connection> object")
    conntimes = 0.0
    outer_contime = time.time()
    try:
        con = hcpsdk.Connection(hcptarget, debuglevel=0, idletime=600, retries=2)
    except Exception as e:
        sys.exit('Exception: {}'.format(str(e)))

    print('--> PUT object {}'.format(T_OBJPATH))
    with open(join(T_INPATH,T_OBJ), 'rb') as inHdl:
        r = con.PUT(T_NAME, inHdl)
    print('PUT result: {}'.format(con.response_status))


    print('--> GET object {}'.format(T_OBJPATH))
    try:
        r = con.HEAD(T_NAME)
    except Exception as e:
        print(str(e))

    print('--> sleep 10 seconds')
    time.sleep(10)
    print('-' * 70)

    print('--> GET object again {}'.format(T_OBJPATH))
    try:
        r = con.GET(T_NAME)
    except Exception as e:
        print('Exception: {}'.format(str(e)))
    else:
        print('--> read')
        x = con.read()
        print('--> read {} bytes'.format(len(x)))

    print('--> Close <connection>')
    con.close()


# -*- coding: utf-8 -*-
# The MIT License (MIT)
#
# Copyright (c) 2014-2016 Thorsten Simons (sw@snomis.de)
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
# the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


class _Version(object):
    """
    Defines version and build for the HCPsdk.
    """
    release = 0
    major = 9
    minor = 4
    build = 5

    fullversion = '{}.{}.{}-{}'.format(release, major, minor, build)

    # noinspection PyUnusedLocal
    def __call__(self, *args, **kwargs):
        return self.__str__()

    def __str__(self):
        return _Version.fullversion





# -*- coding: utf-8 -*-
# The MIT License (MIT)
#
# Copyright (c) 2014-2016 Thorsten Simons (sw@snomis.de)
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
# the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import unittest
from pprint import pprint

import hcpsdk
from datetime import date, timedelta
from collections import OrderedDict
import _io
import init_tests as it


class TestHcpsdk_41_1_Mapi_Logs(unittest.TestCase):
    def setUp(self):
        self.hcptarget = hcpsdk.Target(it.L_ADMIN, it.L_ADMAUTH,
                                       port=it.L_MAPIPORT, dnscache=it.L_DNSCACHE)
        self.logs = hcpsdk.mapi.Logs(self.hcptarget)

    def tearDown(self):
        self.logs.close()
        del self.hcptarget

    def test_1_05_logs_cancel(self):
        """
        Test if we get a dict from status()
        """
        print('test_1_05_logs_cancel:')
        self.assertTrue(self.logs.cancel() == True)

    def test_1_10_logs_prepare(self):
        """
        Test various good/bad parameters
        """
        print('test_1_10_logs_prepare:')

        l = self.logs.prepare()
        pprint(l, indent=4)
        self.assertTrue(l[0] == date(1970,1,1))
        self.assertTrue(l[1] == date.today())
        print('\tno date parameters: pass')

        l = self.logs.prepare(startdate=date.today() - timedelta(days=10),
                              enddate=date.today() - timedelta(days=1))
        pprint(l, indent=4)
        self.assertTrue(l[1] - l[0] == timedelta(days=9))
        print('\tpast 10 days: pass')

        with self.assertRaises(ValueError):
             l = self.logs.prepare(startdate='10/10/2014',
                                   enddate='12/31/2099')
        print('\t\tstartdate: pass')
        with self.assertRaises(ValueError):
             l = self.logs.prepare(startdate=date.today()-timedelta(days=10),
                                   enddate='12/31/2099')
        print('\t\tenddate: pass')
        with self.assertRaises(ValueError):
             l = self.logs.prepare(startdate=date.today()-timedelta(days=10),
                                   enddate=date.today() - timedelta(days=1),
                                   snodes=('s01','s02','s03'))
        print('\t\tsnodes: pass')
        print('\tfalse paramaters: pass')

    def test_1_20_logs_status(self):
        """
        Test if we get a dict from status()
        """
        print('test_1_20_logs_status:')
        l = self.logs.prepare(startdate=date.today()-timedelta(days=10),
                              enddate=date.today() - timedelta(days=1))
        stat = self.logs.status()
        pprint(stat, indent=4)
        self.assertTrue(type(stat) == OrderedDict)

    def test_1_30_logs_download(self):
        """
        Test if we fail when giving a none-file object to download
        """
        print('test_1_30_logs_download:')
        self.logs.prepare(startdate=date.today()-timedelta(days=10),
                          enddate=date.today() - timedelta(days=1))
        with self.assertRaises(hcpsdk.mapi.LogsError):
            fhdl = self.logs.download(5)
        print('\tinvalid file parameter: pass')

        #fhdl = self.logs.download()
        self.assertTrue(type(self.logs.download()) == _io.BufferedRandom)
        print('\tno file parameter: pass')

    def test_1_40_logs_cancel(self):
        """
        Test if we get a dict from status()
        """
        print('test_1_40_logs_cancel:')
        self.logs.prepare(startdate=date.today() - timedelta(days=10),
                              enddate=date.today() - timedelta(days=1))
        self.assertTrue(self.logs.cancel() == True)



# -*- coding: utf-8 -*-
# The MIT License (MIT)
#
# Copyright (c) 2014-2016 Thorsten Simons (sw@snomis.de)
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
# the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

from setuptools import setup, find_packages  # Always prefer setuptools over distutils
from codecs import open  # To use a consistent encoding
from os import path
from hcpsdk.version import _Version
#try:
#except ImportError as e:
#    print('ImportError:', e)

here = path.abspath(path.dirname(__file__))

# Get the long description from the relevant file
with open(path.normpath(path.join(here, 'DESCRIPTION.rst')),encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='hcpsdk',
    # Versions should comply with PEP440. For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # http://packaging.python.org/en/latest/tutorial.html#version

    version=str(_Version()),
    description='An SDK for the Hitachi Content Platform (HCP)',
    long_description=long_description,

    # The project's main homepage.
    url='http://simont3.github.io/hcpsdk',

    # Author details
    author='Thorsten Simons',
    author_email='sw@snomis.de',

    # Choose your license
    license='MIT',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        # 3 - Alpha
        # 4 - Beta
        # 5 - Production/Stable
        'Development Status :: 5 - Production/Stable',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Internet :: WWW/HTTP :: Session',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3.4',

        # more...
        'Operating System :: OS Independent',
        'Natural Language :: English',
    ],

    # What does your project relate to?
    keywords='hcp sdk Hitachi Content Platform',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=find_packages(exclude=[]),

    # List run-time dependencies here. These will be installed by pip when your
    # project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/technical.html#install-requires-vs-requirements-files
    install_requires = ['dnspython>=1.15.0'],

    # List additional groups of dependencies here (e.g. development dependencies).
    # You can install these using the following syntax, for example:
    # $ pip install -e .[dev,test]
    # extras_require = {
    #                  'dev': ['check-manifest'],
    #                  'test': ['coverage'],
    #                  },

    # If there are data files included in your packages that need to be
    # installed, specify them here. If using Python 2.6 or less, then these
    # have to be included in MANIFEST.in as well.
    # package_data={
    #               'sample': ['package_data.dat'],
    #               },

    # Although 'package_data' is the preferred approach, in some case you may
    # need to place data files outside of your packages.
    # see http://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files
    # In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
    # data_files=[('my_data', ['data/data_file'])],

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the Target platform.
    # entry_points={
    #               'console_scripts': ['sample=sample:main',],
    #               },
)



# -*- coding: utf-8 -*-
# The MIT License (MIT)
#
# Copyright (c) 2014-2016 Thorsten Simons (sw@snomis.de)
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
# the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import unittest

import sys
import os.path
sys.path.insert(0, os.path.abspath('..'))
from hcpsdk import ips
import init_tests as it


class TestHcpsdk_10_1_Ips(unittest.TestCase):
    # def setUp(self):
    #     self.T_NS_GOOD = "n1.m.hcp1.snomis.local"
    #     self.T_NS_BAD = "this_wont_work.at-all"
    #     self.T_PORT = 443

    def test_1_05_query_good_fqdn(self):
        """
        Make sure we get a hcpsdk.Target object
        """
        print('test_1_05_query_good_fqdn')
        r = ips.query(it.P_NS_GOOD, cache=it.P_DNSCACHE)
        print(r)
        self.assertTrue(type(r) == ips.Response)
        self.assertTrue(type(r.ips) == list)
        print('fqdn: {} - cache = {}'.format(r.fqdn, r.cache))
        print(r.ips)

    def test_1_10_good_fqdn(self):
        """
        Make sure we get a hcpsdk.Target object
        """
        ipaddrqry = ips.Circle(fqdn=it.P_NS_GOOD, port=it.P_PORT, dnscache=it.P_DNSCACHE)
        self.assertTrue(ipaddrqry._addr() in ipaddrqry._addresses)

    def test_1_20_bad_fqdn(self):
        """
        Makes sure we raise hcpsdk.ips.ipsError on an invalid authority
        (which means, we can't resolve an IP address for it)
        """
        with self.assertRaises(ips.IpsError):
            ips.Circle(fqdn=it.P_NS_BAD, port=it.P_PORT, dnscache=it.P_DNSCACHE)


if __name__ == '__main__':
    unittest.main()



import sys
import time
import pprint
import hcpsdk

print("--> Init <hcptarget> object")
try:
    hcptarget = hcpsdk.target("n1.m.hcp73.archivas.com",
                              "n", "n01", port=443)
    print("   URL:", hcptarget.fqdn)
    print("  PORT:", hcptarget.port)
    print("   IPs:", hcptarget.addresses)
    print("HEADER:", hcptarget.headers)
    print(type(hcptarget))

    docs = ['/rest/test/0072.256kbfile',
            '/rest/test/sqlite-src-3070400.zip',
            '/rest/test/Python-3.2.3.tar',
            '/rest/test/ubuntu-12.04.2-server-amd64.iso',]

    for i in [0]:
        print("<-> "*20)
        print('GET.ing {}'.format(docs[i]))

        try:
            con = hcpsdk.connection(hcptarget, debuglevel=0)
        except Exception as e:
            print('Exception: {}'.format(str(e)))
        else:
            print('\tIP = {}'.format(con.address))
            print('\tConnection time:', con.connect_time)

        time.sleep(0.1)

        try:
            r = con.request('GET', docs[i])
        except Exception as e:
            print('Exception: {}'.format(str(e)))
        else:
            print('\t', con.response_status, con.response_reason)
            size = int(con.getheader('x-hcp-size',0))
            while con.read():
                pass
            print('\tService time: {} ({:5,.2f}Mb/sec)'.format(con.service_time2, size/con.service_time2/1024/1024))



except hcpsdk.HcpsdkError as e:
    sys.exit("Fatal: " + e.errText)






import sys
import pprint
import hcpsdk

print("--> Init <hcptarget> object")
try:
    hcptarget = hcpsdk.target("n1.m.hcp73.archivas.com",
                              "n", "n01", port=443)

    try:
        nso = hcpsdk.namespace.info(hcptarget)
    except hcpsdk.HcpsdkError as e:
        sys.exit(str(e))
    else:
        print("--> actual namespace statistics:")
        r = nso.NSstatistics()
        pprint.pprint(r, width= 80)
        print(' ~> con/service time: {} / {} sec.'.format(nso.connect_time,
                                                          nso.service_time))
        print()

        print("--> list all accessible namespace's settings")
        r = nso.listAccessibleNS()
        pprint.pprint(r, width= 80)
        print(' ~> con/service time: {} / {} sec.'.format(nso.connect_time,
                                                          nso.service_time))
        print()

        print("--> list the actual namespace's settings")
        r = nso.listAccessibleNS(all=True)
        pprint.pprint(r, width= 80)
        print(' ~> con/service time: {} / {} sec.'.format(nso.connect_time,
                                                          nso.service_time))
        print()

        print("--> list the available Retention Classes")
        r = nso.listRetentionClasses()
        pprint.pprint(r, width=80)
        print(' ~> con/service time: {} / {} sec.'.format(nso.connect_time,
                                                          nso.service_time))
        print()

        print("--> list namespace and user permissions")
        r = nso.listPermissions()
        pprint.pprint(r, width=80)
        print(' ~> con/service time: {} / {} sec.'.format(nso.connect_time,
                                                          nso.service_time))
        print()


except hcpsdk.HcpsdkError as e:
    sys.exit("Fatal: " + e.errText)






# -*- coding: utf-8 -*-
# The MIT License (MIT)
#
# Copyright (c) 2014-2016 Thorsten Simons (sw@snomis.de)
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
# the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import sys
import os.path
sys.path.insert(0, os.path.abspath('..'))
import hcpsdk

# primary HCP
P_HCP       = 'hcp73.archivas.com'
P_ADMIN     = 'admin.' + P_HCP
P_TENANT    = 'm.' + P_HCP
P_NS_GOOD   = 'n9.' + P_TENANT
P_NS_BAD    = "this_wont_work.at-all"
P_PORT      = 80
P_SSLPORT   = 443
P_ADMINPORT = 8000
P_MAPIPORT  = 9090
P_DNSCACHE  = True

P_USER      = "n"
P_PASSWORD  = "n01"
P_AUTH      = hcpsdk.NativeAuthorization(P_USER, P_PASSWORD)

P_ADMUSER   = "service"
P_ADMPWD    = "service01"
P_ADMAUTH      = hcpsdk.NativeAuthorization(P_ADMUSER, P_ADMPWD)


# replica HCP
R_HCP       = 'hcp72.archivas.com'
R_ADMIN     = 'admin' + R_HCP
R_TENANT    = 'm.' + R_HCP
R_NS_GOOD   = 'n.' + R_TENANT
R_NS_BAD    = "this_wont_work.at-all"
R_PORT      = P_PORT
R_ADMINPORT = P_ADMINPORT
R_MAPIPORT  = P_MAPIPORT
R_DNSCACHE  = P_DNSCACHE

R_USER      = P_USER
R_PASSWORD  = P_PASSWORD
R_AUTH      = hcpsdk.NativeAuthorization(R_USER, R_PASSWORD)

R_ADMUSER   = "service"
R_ADMPWD    = "service01"
R_ADMAUTH      = hcpsdk.NativeAuthorization(R_ADMUSER, R_ADMPWD)


# primary HCP for mapi.Logs() tests
L_HCP       = 'hcp73.archivas.com'
L_ADMIN     = 'admin.' + L_HCP
L_TENANT    = 'm.' + L_HCP
L_NS_GOOD   = 'n9.' + L_TENANT
L_NS_BAD    = "this_wont_work.at-all"
L_PORT      = 80
L_SSLPORT   = 443
L_ADMINPORT = 8000
L_MAPIPORT  = 9090
L_DNSCACHE  = True

L_USER      = "n"
L_PASSWORD  = "n01"
L_AUTH      = hcpsdk.NativeAuthorization(L_USER, L_PASSWORD)

L_ADMUSER   = "service"
L_ADMPWD    = "service01"
L_ADMAUTH      = hcpsdk.NativeAuthorization(L_ADMUSER, L_ADMPWD)


